# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class AfacProject(models.Model):
    _name = "afac.project"
    _description = "Projets AFAC"

    name = fields.Char("Nom", required=True)
    display_name = fields.Char("Projet", compute="_compute_display_name")
    partner_ids = fields.One2many(
        comodel_name="afac.project.partner",
        inverse_name="project_id",
        string="Participants",
    )
    active = fields.Boolean("Actif", default=True)
    company_id = fields.Many2one(
        comodel_name="res.company",
        string="Structure",
        required=True,
        readonly=True,
        default=lambda self: self.env.company,
    )
    date_start = fields.Date("Date de début")
    date_end = fields.Date("Date de fin")
    description = fields.Text("Description du projet")
    category_ids = fields.One2many(
        comodel_name="afac.project.category",
        inverse_name="project_id",
        string="Sous-projets",
    )

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------
    _sql_constraints = [
        ("name_uniq", "unique (name)", "Le nom du projet doit être unique.")
    ]

    # ------------------------------------------------------
    # Computed field
    # ------------------------------------------------------
    @api.depends("name", "company_id")
    def _compute_display_name(self):
        for project in self:
            if project.sudo().company_id.shortname:
                project.display_name = "%s - %s" % (
                    project.company_id.shortname,
                    project.name,
                )
            else:
                project.display_name = project.name

    # ------------------------------------------------------
    # Buttons
    # ------------------------------------------------------
    def show_partners(self):
        return {
            "name": "Participants",
            "view_mode": "tree,form",
            "res_model": "afac.project.partner",
            "view_id": False,
            "type": "ir.actions.act_window",
            "domain": [("id", "in", self.partner_ids.ids)],
            "context": {
                "default_project_id": self.id,
                "default_company_id": self.company_id.id,
            },
        }
