# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models


class AfacProjectPartner(models.Model):
    _name = "afac.project.partner"
    _description = "Relation contacts et projets"
    _rec_name = "project_id"

    @api.model
    def _get_project_cat(self):
        if self.project_id:
            return [("project_id", "in", self.project_id.ids)]
        elif "default_project_id" in self._context:
            return [("project_id", "=", self._context.get("default_project_id"))]
        else:
            return []

    partner_id = fields.Many2one(
        comodel_name="res.partner", string="Contact", required=True
    )
    project_id = fields.Many2one(
        comodel_name="afac.project",
        string="Projet",
    )
    project_cat_ids = fields.Many2many(
        comodel_name="afac.project.category",
        relation="afac_partner_project_category_rel",
        column1="partner_project_id",
        column2="category_id",
        domain=_get_project_cat,
        string="Sous-Projets",
    )
    company_id = fields.Many2one(
        comodel_name="res.company",
        string="Structure",
        required=True,
        readonly=True,
        default=lambda self: self.env.company,
    )

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------
    _sql_constraints = [
        (
            "partner_project_uniq",
            "unique (partner_id, project_id)",
            "Il n'est pas possible d'enregistrer plusieurs fois "
            "un participant pour un même projet.",
        )
    ]
